<?php

if (!defined('ABSPATH')) {
    exit();
}



class PPT_File_Download_List_Elementor_Widget extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return 'ppt_file_download_list';
    }

    public function get_title()
    {
        return esc_html__('PPT Download List ', 'ppt');
    }

    public function get_icon()
    {
        return 'eicon-download-button';
    }

    public function get_categories()
    {
        return ['ppt-category'];
    }

    protected function register_controls()
    {
        $this->start_controls_section('content_section', [
            'label' => esc_html__('Content', 'ppt'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        ]);

        $repeater = new \Elementor\Repeater();

        $repeater->add_control('title', [
            'label' => esc_html__('File Title', 'ppt'),
            'type' => \Elementor\Controls_Manager::TEXT,
            'label_block' => true,
        ]);

        $repeater->add_control('date', [
            'label' => esc_html__('File Date', 'ppt'),
            'type' => \Elementor\Controls_Manager::TEXT,
            'label_block' => true,
        ]);
        
        $repeater->add_control('size', [
            'label' => esc_html__('File Size', 'ppt'),
            'type' => \Elementor\Controls_Manager::TEXT,
            'label_block' => true,
        ]);

        $repeater->add_control('image', [
            'label' => esc_html__('File Image', 'ppt'),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
            'label_block' => true,
        ]);
        
        $repeater->add_control('button_text', [
            'label' => esc_html__('Button Text', 'ppt'),
            'type' => \Elementor\Controls_Manager::TEXT,
            'label_block' => true,
        ]);
        
        $repeater->add_control('button_link', [
            'label' => esc_html__('Button Link', 'ppt'),
            'type' => \Elementor\Controls_Manager::TEXT,
            'label_block' => true,
        ]);


        $this->add_control('list', [
            'label' => esc_html__('List', 'ppt'),
            'type' => \Elementor\Controls_Manager::REPEATER,
            'fields' => $repeater->get_controls(),
            'title_field' => '{{{ title }}}',
        ]);

        $this->end_controls_section();

        $this->start_controls_section('style_section', [
            'label' => esc_html__('Style', 'ppt'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        ]);



        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Title Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dowload-list-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_size',
            [
                'label' => esc_html__( 'Title Font Size', 'ppt' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 25,
                ],
                'selectors' => [
                    '{{WRAPPER}} .dowload-list-title' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        

        $this->add_control(
            'date_size_color',
            [
                'label' => esc_html__( 'Date & Size Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dowload-list-metadata-list' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'date_size_size',
            [
                'label' => esc_html__( 'Date & Size Font Size', 'ppt' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 20,
                ],
                'selectors' => [
                    '{{WRAPPER}} .dowload-list-metadata-list' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        
        $this->add_control(
            'button_background_color',
            [
                'label' => esc_html__( 'Button Background Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dowload-list-btn-label' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        
        $this->add_control(
            'button_background_color_hover',
            [
                'label' => esc_html__( 'Button Hover Background Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ppt-download-button-primary:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );
 

        $this->end_controls_section();
    }

protected function render() {
        $settings = $this->get_settings_for_display();
    
        if ($settings['list']) {
            echo '<ul class="dowload-list">';
            foreach ($settings['list'] as $index => $list) {
                echo '<li class="dowload-list-item">';
                echo '<div class="download-flex download-items-center">';
                if (!empty($list['image']['url'])) {
                    echo '<img class="dowload-list-file-icon ppt-download-icon" src="' . esc_url($list['image']['url']) . '">';
                }
                echo '<div>';
                echo '<h3 class="dowload-list-title">' . esc_html($list['title']) . '</h3>';
                echo '<ul class="dowload-list-metadata-list">';
                if (!empty($list['date'])) {
                    echo '<li>' . esc_html($list['date']) . '</li>';
                }
                if (!empty($list['size'])) {
                    echo '<li>' . esc_html($list['size']) . '</li>';
                }
                echo '</ul>';  
                echo '</div>'; 
                echo '</div>';
                if (!empty($list['button_text'])) {
                   
                    $link_key = 'button_link_' . $index;
                    $this->add_link_attributes($link_key, $list['button_link']);
                    echo '<a ' . $this->get_render_attribute_string($link_key) . '>';
                    echo '<button class="dowload-list-btn ppt-download-button ppt-download-button-primary">';
                    echo '<span class="dowload-list-btn-label">' . esc_html($list['button_text']) . '</span>';
                    echo '<div class="dowload-list-icon-wrapper">';
                    echo '<svg class="dowload-list-icon" viewBox="0 0 20 20" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="2">';
                    echo '<g class="dowload-list-icon-group">';
                        echo '<line x1="10" y1="18" x2="10" y2="2" />';
                        echo '<line x1="5" y1="13" x2="10" y2="18" />';
                        echo '<line x1="10" y1="18" x2="15" y2="13" />';
                        echo '<path d="M10,18a8,8,0,1,1,8-8,8,8,0,0,1-8,8" />';
                        echo '<path d="M2,10a8,8,0,1,1,8,8" />';
                        echo '<polyline points="2 10 7 15 18 4" />';
                        echo '<path d="M10,2a8,8,0,0,1,0,16" />';
                        echo '<line x1="10" y1="2" x2="10" y2="12" />';
                        echo '<circle cx="10" cy="17.5" r="1.5" fill="currentColor" stroke="none" />';
                    echo '</g>';
                    echo '</svg>';
                    echo '</div>';  
                    echo '</button>';
                    echo '</a>';
                }
                echo '</li>'; 
            }
            echo '</ul>'; 
        }
    }
}